

import include from './include'; /**
                                  * Copyright (c) 2015-present, Parse, LLC.
                                  * All rights reserved.
                                  *
                                  * This source code is licensed under the BSD-style license found in the
                                  * LICENSE file in the root directory of this source tree. An additional grant
                                  * of patent rights can be found in the PATENTS file in the same directory.
                                  *
                                  * 
                                  */

export default function (CoreManager, Exports) {

  Exports.send =

  /**
   * Parse.Mails provides an interface to Parse's send email
   * backend.
   *
   * @class Parse.Mails
   * @static
   * @hideconstructor
   */

  /**
   * Send method will let user send email using Parse server Mail backend
   *
   * To send an email, consider the
   * following:
   * <pre>
   * var body = {
   *  to:["rohit_waghmare@altizon.com"],
   *  subject:"APM Test Email_2",
   *  text:"This is going to be rocking.",
   * };
   * Parse.Mail.send(body);
   * </pre>
   *
   * 
   * @method send
   * @name Parse.Mail.send
   * @param {MailBody} body Mail body to be send along with receiver email ids
   * @return {Parse.Promise} A promise that is resolved when the round-trip
   * to the server completes.
   */
  function (body, options) {

    if (typeof body["to"] === 'string') {
      let name = body["to"] || '';
      name = name.replace(/^\s*/, '');
      name = name.replace(/\s*$/, '');
      if (name.length === 0) {
        throw new TypeError('Email recipients  must be provided');
      }
    } else {
      if (body["to"].length === 0) {
        throw new TypeError('Email recipients  must be provided');
      }
    }

    options = options || {};
    return CoreManager.getMailsController().send(body)._thenRunCallbacks(options);
  };

  var DefaultController = {
    send(body) {
      var RESTController = CoreManager.getRESTController();
      return RESTController.request('POST', 'mail/send', body);
    }
  };

  CoreManager.setMailsController(DefaultController);
}